@@ -118,7 +118,7 @@ expose_stan_functions <- function(stanmodel, env = globalenv()) {
   # convert inline declarations to Rcpp export declarations
   lines <- gsub("^inline$", "// \\[\\[Rcpp::export\\]\\]", lines)
   
-  ints <- grep("^int$", lines)
+  ints <- sort(c(grep("^int$", lines), grep("^std::vector<.*int>", lines)))
   for (i in rev(ints))
     lines <- append(lines, "// [[Rcpp::export]]", i - 1L)
 
@@ -140,8 +140,8 @@ expose_stan_functions <- function(stanmodel, env = globalenv()) {
   }
 
   # special cases
-  ODE_lines <- grep("integrate_ode(", lines, fixed = TRUE)
-  ODE_statements <- grep("integrate_ode(", lines, fixed = TRUE, value = TRUE)
+  ODE_lines <- grep("integrate_ode", lines, fixed = TRUE)
+  ODE_statements <- grep("integrate_ode", lines, fixed = TRUE, value = TRUE)
 
   print_lines <- grep("if (pstream__)", lines, fixed = TRUE)
   print_statements <- grep("if (pstream__)", lines, fixed = TRUE, value = TRUE)
