@@ -105,13 +105,13 @@ setMethod("vb", "stanmodel",
                    algorithm = c("meanfield", "fullrank"), ...) {
             stan_fit_cpp_module <- object@mk_cppmodule(object)
             if (is.list(data) & !is.data.frame(data)) {
-              parsed_data <- parse_data(get_cppcode(object))
+              parsed_data <- with(data, parse_data(get_cppcode(object)))
               if (!is.list(parsed_data)) {
                 message("failed to get names of data from the model; sampling not done")
                 return(invisible(new_empty_stanfit(object)))
               }
-              for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
-              parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
+              # for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
+              # parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
               data <- parsed_data
             } else if (is.character(data)) { # names of objects
               data <- try(mklist(data))
@@ -263,13 +263,13 @@ setMethod("optimizing", "stanmodel",
             stan_fit_cpp_module <- object@mk_cppmodule(object)
 
             if (is.list(data) & !is.data.frame(data)) {
-              parsed_data <- parse_data(get_cppcode(object))
+              parsed_data <- with(data, parse_data(get_cppcode(object)))
               if (!is.list(parsed_data)) {
                 message("failed to get names of data from the model; sampling not done")
                 return(invisible(new_empty_stanfit(object)))
               }
-              for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
-              parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
+              # for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
+              # parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
               data <- parsed_data
             } else if (is.character(data)) { # names of objects
               data <- try(mklist(data))
@@ -394,13 +394,13 @@ setMethod("sampling", "stanmodel",
                    show_messages = TRUE, ...) {
             objects <- ls()
             if (is.list(data) & !is.data.frame(data)) {
-              parsed_data <- try(parse_data(get_cppcode(object)))
+              parsed_data <- with(data, parse_data(get_cppcode(object)))
               if (!is.list(parsed_data)) {
                 message("failed to get names of data from the model; sampling not done")
                 return(invisible(new_empty_stanfit(object)))
               }
-              for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
-              parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
+              # for (nm in names(data)) parsed_data[[nm]] <- data[[nm]]
+              # parsed_data <- parsed_data[!sapply(parsed_data, is.null)]
               data <- parsed_data
             } else if (is.character(data)) { # names of objects
               data <- try(mklist(data))
@@ -472,10 +472,19 @@ setMethod("sampling", "stanmodel",
                 .dotlist$chain_id <- i
                 if(is.list(.dotlist$init)) .dotlist$init <- .dotlist$init[i]
                 if(is.character(.dotlist$sample_file)) {
-                  .dotlist$sample_file <- paste0(.dotlist$sample_file, i)
+                  if (grepl("\\.csv$", .dotlist$sample_file))
+                    .dotlist$sample_file <- sub("\\.csv$", paste0("_", i, ".csv"), 
+                                                .dotlist$sample_file)
+                  else .dotlist$sample_file <- paste0(.dotlist$sample_file, 
+                                                      "_", i, ".csv")
                 }
                 if(is.character(.dotlist$diagnostic_file)) {
-                  .dotlist$diagnostic_file <- paste0(.dotlist$diagnostic_file, i)
+                  if (grepl("\\.csv$", .dotlist$diagnostic_file))
+                    .dotlist$diagnostic_file <- sub("\\.csv$", paste0("_", i, ".csv"),
+                                                    .dotlist$diagnostic_file)
+                  else
+                    .dotlist$diagnostic_file <- paste0(.dotlist$diagnostic_file, 
+                                                       "_", i, ".csv")
                 }
                 Sys.sleep(0.5 * i)
                 out <- do.call(rstan::sampling, args = .dotlist)
@@ -484,7 +493,8 @@ setMethod("sampling", "stanmodel",
               if ( .Platform$OS.type == "unix" && 
                    (!interactive() || isatty(stdout())) ) {
                 nfits <- parallel::mclapply(1:chains, FUN = callFun, 
-                                            mc.preschedule = FALSE, mc.cores = cores)
+                                            mc.preschedule = FALSE, 
+                                            mc.cores = min(chains, cores))
               }
               else {
                 tfile <- tempfile()
@@ -637,7 +647,7 @@ setMethod("sampling", "stanmodel",
                 report <- strtrim(report, width = 100)
                 if (length(report) > 0) {
                   tab <- sort(table(report), decreasing = TRUE)
-                  msg <- paste("The following numerical problems occured",
+                  msg <- paste("The following numerical problems occurred",
                                "the indicated number of times on chain", 
                                cid)
                   if (.Platform$OS.type == "windows") print(msg)
@@ -649,14 +659,14 @@ setMethod("sampling", "stanmodel",
                     print("When a numerical problem occurs, the Hamiltonian proposal gets rejected.")
                     print("See http://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
                     print(paste("If the number in the 'count' column is small, ",
-                                "do not ask about this message on stan-users."))
+                                "there is no need to ask about this message on stan-users."))
                   }
                   else {
                     message(paste(capture.output(print(mat)), collapse = "\n"))
                     message("When a numerical problem occurs, the Hamiltonian proposal gets rejected.")
                     message("See http://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
                     message("If the number in the 'count' column is small, ",
-                            "do not ask about this message on stan-users.")
+                            "there is no need to ask about this message on stan-users.")
                   }
                 }
               }
